@@ -297,7 +297,13 @@ class Address(object):
             if not privateKey:
                 privKey = curve.generatePrivateKey(accountSeedHash)
             else:
+                # clamping: https://neilmadden.blog/2020/05/28/whats-the-curve25519-clamping-all-about/
                 privKey = base58.b58decode(privateKey)
+                privKeyArray = bytearray(privKey)
+                privKeyArray[0] &= 248;
+                privKeyArray[31] &= 127;
+                privKeyArray[31] |= 64;
+                privKey = bytes(privKeyArray)
             pubKey = curve.generatePublicKey(privKey)
         unhashedAddress = chr(1) + str(self.pywaves.CHAIN_ID) + crypto.hashChain(pubKey)[0:20]
         addressHash = crypto.hashChain(crypto.str2bytes(unhashedAddress))[0:4]
@@ -805,6 +811,45 @@ class Address(object):
             return amountBalance, priceBalance
 
     def lease(self, recipient, amount, txFee=pywaves.DEFAULT_LEASE_FEE, timestamp=0):
+        if not self.privateKey:
+            msg = 'Private key required'
+            logging.error(msg)
+            self.pywaves.throw_error(msg)
+        elif amount <= 0:
+            msg = 'Amount must be > 0'
+            logging.error(msg)
+            self.pywaves.throw_error(msg)
+        elif not self.pywaves.OFFLINE and self.balance() < amount + txFee:
+            msg = 'Insufficient Waves balance'
+            logging.error(msg)
+            self.pywaves.throw_error(msg)
+        else:
+            if timestamp == 0:
+                timestamp = int(time.time() * 1000)
+            sData = b'\x08' + \
+                    b'\x02' + \
+                    b'\x00' + \
+                    base58.b58decode(self.publicKey) + \
+                    base58.b58decode(recipient.address) + \
+                    struct.pack(">Q", amount) + \
+                    struct.pack(">Q", txFee) + \
+                    struct.pack(">Q", timestamp)
+
+            signature = crypto.sign(self.privateKey, sData)
+            data = json.dumps({
+                "type": 8,
+                "senderPublicKey": self.publicKey,
+                "recipient": recipient.address,
+                "amount": amount,
+                "fee": txFee,
+                "timestamp": timestamp,
+                "proofs": [ signature ],
+                "version": 2
+            })
+            req = self.pywaves.wrapper('/transactions/broadcast', data)
+            return req
+
+    '''def lease(self, recipient, amount, txFee=pywaves.DEFAULT_LEASE_FEE, timestamp=0):
         if not self.privateKey:
             msg = 'Private key required'
             logging.error(msg)
@@ -836,7 +881,7 @@ class Address(object):
                 "signature": signature
             })
             req = self.pywaves.wrapper('/leasing/broadcast/lease', data)
-            return req
+            return req'''
 
     def leaseCancel(self, leaseId, txFee=pywaves.DEFAULT_LEASE_FEE, timestamp=0):
         if not self.privateKey:
